Module: Schema::Parsers
- Defined in:
- lib/schema.rb,
lib/schema/parsers/hash.rb,
lib/schema/parsers/json.rb,
lib/schema/parsers/array.rb,
lib/schema/parsers/common.rb
Overview
Schema::Parsers are used to convert values into the correct data type
Schema::Parsers are used to convert values into the correct data type